<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2025 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */

namespace Drupal\recipe_code_installer\Application\UseCase\InstallBundledModule;

use Drupal\Core\Recipe\Recipe;

/**
 * Contract for installing bundled module code from a recipe.
 *
 * This interface defines the service responsible for extracting and installing
 * custom module code bundled within a recipe.
 *
 * @internal This interface is not part of the module's public programming API.
 */
interface InstallBundledModuleFromRecipeInterface {

  /**
   * Installs the bundled module specified in a recipe.
   *
   * @param \Drupal\Core\Recipe\Recipe $recipe
   *   The recipe containing the module to be installed.
   */
  public function __invoke(Recipe $recipe): void;

}
